AutoSFInteraction
=================

.. currentmodule:: pykeen.nn.modules

.. autoclass:: AutoSFInteraction
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~AutoSFInteraction.extend
      ~AutoSFInteraction.from_searched_sf
      ~AutoSFInteraction.func
      ~AutoSFInteraction.latex_visualize

   .. rubric:: Methods Documentation

   .. automethod:: extend
   .. automethod:: from_searched_sf
   .. automethod:: func
   .. automethod:: latex_visualize
